@@ -1,4 +1,4 @@
-# Copyright 2018-2022 contributors to the OpenLineage project
+# Copyright 2018-2023 contributors to the OpenLineage project
 # SPDX-License-Identifier: Apache-2.0
 
 import copy
@@ -6,52 +6,54 @@ import logging
 import os
 from collections import defaultdict
 from datetime import datetime
-from typing import Optional, List, Union, Dict
+from typing import Dict, List, Optional, Union
 from urllib.parse import urlparse
 from uuid import uuid4
 
-from great_expectations.checkpoint import ValidationAction
-from great_expectations.core import ExpectationSuiteValidationResult
-from great_expectations.data_context.types.resource_identifiers import (
-    ValidationResultIdentifier,
-)
-from great_expectations.dataset import (
-    SqlAlchemyDataset,
-    PandasDataset,
-    Dataset as GEDataset,
-)
-from great_expectations.execution_engine import (
-    SqlAlchemyExecutionEngine,
-    PandasExecutionEngine,
-)
-from great_expectations.execution_engine.sqlalchemy_batch_data import (
-    SqlAlchemyBatchData,
-)
-from great_expectations.validator.validator import Validator
-
 from openlineage.client import OpenLineageClient, OpenLineageClientOptions
 from openlineage.client.facet import (
-    ParentRunFacet,
-    DocumentationJobFacet,
-    SourceCodeLocationJobFacet,
-    DataQualityMetricsInputDatasetFacet,
+    BaseFacet,
     ColumnMetric,
+    DataQualityMetricsInputDatasetFacet,
+    DocumentationJobFacet,
+    ParentRunFacet,
+    SourceCodeLocationJobFacet,
 )
-from openlineage.client.run import RunEvent, RunState, Run, Job
+from openlineage.client.run import Job, Run, RunEvent, RunState
 from openlineage.client.serde import Serde
-from openlineage.common.dataset import Dataset, Source, Field
+from openlineage.common.dataset import Dataset, Field, Source
 from openlineage.common.dataset import Dataset as OLDataset
 from openlineage.common.provider.great_expectations.facets import (
     GreatExpectationsAssertionsDatasetFacet,
     GreatExpectationsRunFacet,
 )
 from openlineage.common.provider.great_expectations.results import (
-    EXPECTATIONS_PARSERS,
     COLUMN_EXPECTATIONS_PARSER,
+    EXPECTATIONS_PARSERS,
     GreatExpectationsAssertion,
 )
+from openlineage.common.provider.snowflake import fix_snowflake_sqlalchemy_uri
 from openlineage.common.sql import parse
 
+from great_expectations.checkpoint import ValidationAction
+from great_expectations.core import ExpectationSuiteValidationResult
+from great_expectations.data_context.types.resource_identifiers import (
+    ValidationResultIdentifier,
+)
+from great_expectations.dataset import Dataset as GEDataset
+from great_expectations.dataset import (
+    PandasDataset,
+    SqlAlchemyDataset,
+)
+from great_expectations.execution_engine import (
+    PandasExecutionEngine,
+    SqlAlchemyExecutionEngine,
+)
+from great_expectations.execution_engine.sqlalchemy_batch_data import (
+    SqlAlchemyBatchData,
+)
+from great_expectations.validator.validator import Validator
+
 # There is no guarantee that SqlAlchemy is available with Great Expectations.
 # Especially, it could be used only with Pandas datasets, in which case
 # we shouldn't try to import it.
@@ -60,9 +62,9 @@ try:
     from sqlalchemy import MetaData, Table
     from sqlalchemy.engine import Connection
 except ImportError:
-    MetaData = None
-    Table = None
-    Connection = None
+    MetaData = None  # type: ignore
+    Table = None  # type: ignore
+    Connection = None  # type: ignore
 
 
 class OpenLineageValidationAction(ValidationAction):
@@ -138,27 +140,17 @@ class OpenLineageValidationAction(ValidationAction):
         payload=None,
     ):
         # Initialize logger here so that the action is serializable until it actually runs
-        self.log = logging.getLogger(
-            self.__class__.__module__ + "." + self.__class__.__name__
-        )
+        self.log = logging.getLogger(self.__class__.__module__ + "." + self.__class__.__name__)
 
         datasets = []
         if isinstance(data_asset, SqlAlchemyDataset):
-            datasets = self._fetch_datasets_from_sql_source(
-                data_asset, validation_result_suite
-            )
+            datasets = self._fetch_datasets_from_sql_source(data_asset, validation_result_suite)
         elif isinstance(data_asset, PandasDataset):
-            datasets = self._fetch_datasets_from_pandas_source(
-                data_asset, validation_result_suite
-            )
+            datasets = self._fetch_datasets_from_pandas_source(data_asset, validation_result_suite)
         elif isinstance(data_asset.execution_engine, SqlAlchemyExecutionEngine):
-            datasets = self._fetch_datasets_from_sql_source(
-                data_asset, validation_result_suite
-            )
+            datasets = self._fetch_datasets_from_sql_source(data_asset, validation_result_suite)
         elif isinstance(data_asset.execution_engine, PandasExecutionEngine):
-            datasets = self._fetch_datasets_from_pandas_source(
-                data_asset, validation_result_suite
-            )
+            datasets = self._fetch_datasets_from_pandas_source(data_asset, validation_result_suite)
         run_facets = {}
         if self.parent_run_id is not None:
             run_facets.update(
@@ -173,19 +165,11 @@ class OpenLineageValidationAction(ValidationAction):
 
         # workaround for GE v2 and v3 API difference
         suite_meta = dict(
-            {
-                key: self._ser(value)
-                for key, value in copy.deepcopy(validation_result_suite.meta).items()
-            }
+            {key: self._ser(value) for key, value in copy.deepcopy(validation_result_suite.meta).items()}
         )
         if "expectation_suite_meta" not in suite_meta:
             suite_meta["expectation_suite_meta"] = dict(
-                {
-                    key: self._ser(value)
-                    for key, value in copy.deepcopy(
-                        validation_result_suite.meta
-                    ).items()
-                }
+                {key: self._ser(value) for key, value in copy.deepcopy(validation_result_suite.meta).items()}
             )
         run_facets.update(
             {
@@ -194,19 +178,11 @@ class OpenLineageValidationAction(ValidationAction):
                 )
             }
         )
-        job_facets = {}
+        job_facets: Dict[str, BaseFacet] = {}
         if self.job_description:
-            job_facets.update(
-                {"documentation": DocumentationJobFacet(self.job_description)}
-            )
+            job_facets["documentation"] = DocumentationJobFacet(self.job_description)
         if self.code_location:
-            job_facets.update(
-                {
-                    "sourceCodeLocation": SourceCodeLocationJobFacet(
-                        "", self.code_location
-                    )
-                }
-            )
+            job_facets["sourceCodeLocation"] = SourceCodeLocationJobFacet(type="", url=self.code_location)
 
         job_name = self.job_name
         if self.job_name is None:
@@ -222,7 +198,7 @@ class OpenLineageValidationAction(ValidationAction):
             job=Job(self.namespace, job_name, facets=job_facets),
             inputs=datasets,
             outputs=[],
-            producer="https://github.com/OpenLineage/OpenLineage/tree/$VERSION/integration/common/openlineage/provider/great_expectations",  # noqa
+            producer="https://github.com/OpenLineage/OpenLineage/tree/$VERSION/integration/common/openlineage/provider/great_expectations",
         )
         if self.do_publish:
             self.openlineage_client.emit(run_event)
@@ -239,7 +215,7 @@ class OpenLineageValidationAction(ValidationAction):
         self,
         data_asset: Union[PandasDataset, Validator],
         validation_result_suite: ExpectationSuiteValidationResult,
-    ) -> List[OLDataset]:  # noqa
+    ) -> List[OLDataset]:
         """
         Generate a list of OpenLineage Datasets from a PandasDataset
         :param data_asset:
@@ -250,14 +226,12 @@ class OpenLineageValidationAction(ValidationAction):
             if data_asset.batch_kwargs.__contains__("path"):
                 path = data_asset.batch_kwargs.get("path")
                 if path.startswith("/"):
-                    path = "file://{}".format(path)
+                    path = f"file://{path}"
                 parsed_url = urlparse(path)
                 columns = [
                     Field(
                         name=col,
-                        type=str(data_asset[col].dtype)
-                        if data_asset[col].dtype is not None
-                        else "UNKNOWN",
+                        type=str(data_asset[col].dtype) if data_asset[col].dtype is not None else "UNKNOWN",
                     )
                     for col in data_asset.columns
                 ]
@@ -281,14 +255,12 @@ class OpenLineageValidationAction(ValidationAction):
             if path is None:
                 return []
             if path.startswith("/"):
-                path = "file://{}".format(path)
+                path = f"file://{path}"
             parsed_url = urlparse(path)
             columns = [
                 Field(
                     name=col,
-                    type=str(data_asset[col].dtype)
-                    if data_asset[col].dtype is not None
-                    else "UNKNOWN",
+                    type=str(data_asset[col].dtype) if data_asset[col].dtype is not None else "UNKNOWN",
                 )
                 for col in batch_data.columns
             ]
@@ -305,7 +277,7 @@ class OpenLineageValidationAction(ValidationAction):
         self,
         data_asset: Union[SqlAlchemyDataset, Validator],
         validation_result_suite: ExpectationSuiteValidationResult,
-    ) -> List[OLDataset]:  # noqa
+    ) -> List[OLDataset]:
         """
         Generate a list of OpenLineage Datasets from a SqlAlchemyDataset.
         :param data_asset:
@@ -316,13 +288,9 @@ class OpenLineageValidationAction(ValidationAction):
         if isinstance(data_asset, SqlAlchemyDataset):
             if data_asset.generated_table_name is not None:
                 custom_sql = data_asset.batch_kwargs.get("query")
-                parsed_sql = parse(
-                    custom_sql, dialect=data_asset.engine.dialect.name.lower()
-                )
+                parsed_sql = parse(custom_sql, dialect=data_asset.engine.dialect.name.lower())
                 return [
-                    self._get_sql_table(
-                        data_asset, metadata, t.schema, t.name, validation_result_suite
-                    )
+                    self._get_sql_table(data_asset, metadata, t.schema, t.name, validation_result_suite)
                     for t in parsed_sql.in_tables
                 ]
             return [
@@ -343,13 +311,9 @@ class OpenLineageValidationAction(ValidationAction):
                 else None
             )
             if custom_sql:
-                parsed_sql = parse(
-                    custom_sql, dialect=data_asset.execution_engine.dialect_name
-                )
+                parsed_sql = parse(custom_sql, dialect=data_asset.execution_engine.dialect_name)
                 return [
-                    self._get_sql_table(
-                        batch_data, metadata, t.schema, t.name, validation_result_suite
-                    )
+                    self._get_sql_table(batch_data, metadata, t.schema, t.name, validation_result_suite)
                     for t in parsed_sql.in_tables
                 ]
             table_name = batch["batch_spec"]["table_name"]
@@ -381,20 +345,23 @@ class OpenLineageValidationAction(ValidationAction):
         :param data_asset:
         :return:
         """
-        engine = (
-            data_asset.engine
-            if isinstance(data_asset, SqlAlchemyDataset)
-            else data_asset._engine
-        )
+        engine = data_asset.engine if isinstance(data_asset, SqlAlchemyDataset) else data_asset._engine
         if isinstance(engine, Connection):
             engine = engine.engine
         datasource_url = engine.url
 
+        if engine.dialect.name.lower() == "snowflake":
+            if engine.connection_string:
+                datasource_url = engine.connection_string
+            else:
+                datasource_url = engine.url
+            datasource_url = fix_snowflake_sqlalchemy_uri(datasource_url)
+
         # bug in sql parser doesn't strip ` character from bigquery tables
         if table_name.endswith("`") or table_name.startswith("`"):
             table_name = table_name.replace("`", "")
         if engine.dialect.name.lower() == "bigquery":
-            schema = "{}.{}".format(datasource_url.host, datasource_url.database)
+            schema = f"{datasource_url.host}.{datasource_url.database}"
 
         table = Table(table_name, meta, autoload_with=engine)
 
@@ -407,7 +374,7 @@ class OpenLineageValidationAction(ValidationAction):
             for key, col in table.columns.items()
         ]
 
-        name = table_name if schema is None else "{}.{}".format(schema, table_name)
+        name = table_name if schema is None else f"{schema}.{table_name}"
 
         results_facet = self.results_facet(validation_result_suite)
         return Dataset(
@@ -432,9 +399,7 @@ class OpenLineageValidationAction(ValidationAction):
             scheme=url.scheme,
             authority=url.hostname,
             # Remove credentials from the URL if present
-            connection_url=url._replace(
-                netloc=url.hostname, query=None, fragment=None
-            ).geturl(),
+            connection_url=url._replace(netloc=url.hostname, query=None, fragment=None).geturl(),
         )
 
     def results_facet(self, validation_result: ExpectationSuiteValidationResult):
@@ -478,7 +443,6 @@ class OpenLineageValidationAction(ValidationAction):
             expectations_results = validation_result["results"]
             for expectation in expectations_results:
                 for parser in EXPECTATIONS_PARSERS:
-
                     # accept possible duplication, should have no difference in results
                     if parser.can_accept(expectation):
                         result = parser.parse_expectation_result(expectation)
@@ -486,19 +450,13 @@ class OpenLineageValidationAction(ValidationAction):
                 for parser in COLUMN_EXPECTATIONS_PARSER:
                     if parser.can_accept(expectation):
                         result = parser.parse_expectation_result(expectation)
-                        facet_data["columnMetrics"][result.column_id][
-                            result.facet_key
-                        ] = result.value
+                        facet_data["columnMetrics"][result.column_id][result.facet_key] = result.value
 
             for key in facet_data["columnMetrics"].keys():
-                facet_data["columnMetrics"][key] = ColumnMetric(
-                    **facet_data["columnMetrics"][key]
-                )
-            return DataQualityMetricsInputDatasetFacet(**facet_data)
+                facet_data["columnMetrics"][key] = ColumnMetric(**facet_data["columnMetrics"][key])
+            return DataQualityMetricsInputDatasetFacet(**facet_data)  # type: ignore[arg-type]
         except ValueError:
-            self.log.exception(
-                "Great Expectations's CheckpointResult object does not have expected key"
-            )
+            self.log.exception("Great Expectations's CheckpointResult object does not have expected key")
         return None
 
     def parse_assertions(
@@ -510,19 +468,13 @@ class OpenLineageValidationAction(ValidationAction):
             for expectation in validation_result.results:
                 assertions.append(
                     GreatExpectationsAssertion(
-                        expectationType=expectation["expectation_config"][
-                            "expectation_type"
-                        ],
+                        expectationType=expectation["expectation_config"]["expectation_type"],
                         success=expectation["success"],
-                        column=expectation["expectation_config"]["kwargs"].get(
-                            "column", None
-                        ),
+                        column=expectation["expectation_config"]["kwargs"].get("column", None),
                     )
                 )
 
             return GreatExpectationsAssertionsDatasetFacet(assertions)
         except ValueError:
-            self.log.exception(
-                "Great Expectations's CheckpointResult object does not have expected key"
-            )
+            self.log.exception("Great Expectations's CheckpointResult object does not have expected key")
         return None
