@@ -20,18 +20,18 @@ def any(result: Any):
 
 def is_datetime(result: Any):
     try:
-        x = parse(result)  # noqa
+        parse(result)
         return "true"
-    except:  # noqa
+    except Exception:
         pass
     return "false"
 
 
 def is_uuid(result: Any):
     try:
-        uuid.UUID(result)  # noqa
+        uuid.UUID(result)
         return "true"
-    except:  # noqa
+    except Exception:
         pass
     return "false"
 
@@ -67,13 +67,13 @@ def url_path(url) -> str:
 
 def setup_jinja() -> Environment:
     env = Environment()
-    env.globals['any'] = any
-    env.globals['is_datetime'] = is_datetime
-    env.globals['is_uuid'] = is_uuid
-    env.globals['env_var'] = env_var
-    env.globals['not_match'] = not_match
-    env.filters['url_scheme_authority'] = url_scheme_authority
-    env.filters['url_path'] = url_path
+    env.globals["any"] = any
+    env.globals["is_datetime"] = is_datetime
+    env.globals["is_uuid"] = is_uuid
+    env.globals["env_var"] = env_var
+    env.globals["not_match"] = not_match
+    env.filters["url_scheme_authority"] = url_scheme_authority
+    env.filters["url_path"] = url_path
     return env
 
 
@@ -91,8 +91,10 @@ def match(expected, result) -> bool:
                 log.error(f"Key {k} not in received event {result}\nExpected {expected}")
                 return False
             if not match(v, result[k]):
-                log.error(f"For key {k}, expected value {v} not equals received {result[k]}"
-                          f"\nExpected {expected}, request {result}")
+                log.error(
+                    f"For key {k}, expected value {v} not equals received {result[k]}"
+                    f"\nExpected {expected}, request {result}"
+                )
                 return False
     elif isinstance(expected, list):
         if len(expected) != len(result):
@@ -102,12 +104,12 @@ def match(expected, result) -> bool:
         # Try to resolve case where we have wrongly sorted lists by looking at name attr
         # If name is not present then assume that lists are sorted
         for i, x in enumerate(expected):
-            if 'name' in x:
+            if "name" in x:
                 matched = False
                 for y in result:
-                    if 'name' in y:
-                        expected_name = env.from_string(x['name']).render()
-                        result_name = env.from_string(y['name']).render()
+                    if "name" in y:
+                        expected_name = env.from_string(x["name"]).render()
+                        result_name = env.from_string(y["name"]).render()
                         if expected_name == result_name:
                             if not match(x, y):
                                 log.error(f"List not matched {x} where {y}")
@@ -123,16 +125,17 @@ def match(expected, result) -> bool:
             else:
                 if not match(x, result[i]):
                     log.error(
-                        f"List not matched at {i}\n" +
-                        f"  expected:\n{json.dumps(x)}\n" +
-                        f"  result: \n{json.dumps(result[i])}")
+                        f"List not matched at {i}\n"
+                        + f"  expected:\n{json.dumps(x)}\n"
+                        + f"  result: \n{json.dumps(result[i])}"
+                    )
                     return False
     elif isinstance(expected, str):
-        if '{{' in expected:
+        if "{{" in expected:
             # Evaluate jinja: in some cases, we want to check only if key exists, or if
             # value has the right type
             rendered = env.from_string(expected).render(result=result)
-            if rendered == 'true' or rendered == result:
+            if rendered == "true" or rendered == result:
                 return True
             log.error(f"Rendered value {rendered} does not equal 'true' or {result}")
             return False
