@@ -1,7 +1,7 @@
-# Copyright 2018-2022 contributors to the OpenLineage project
+# Copyright 2018-2023 contributors to the OpenLineage project
 # SPDX-License-Identifier: Apache-2.0
 
-from typing import Dict, Any, List, Optional
+from typing import Any, Dict, List, Optional
 
 
 def get_from_nullable_chain(source: Any, chain: List[str]) -> Optional[Any]:
@@ -51,7 +51,7 @@ def parse_single_arg(args, keys: List[str], default=None) -> Optional[str]:
     for key in keys:
         for i, arg in enumerate(args):
             if arg == key and len(args) > i:
-                return args[i+1]
+                return args[i + 1]
             if arg.startswith(f"{key}="):
                 return arg.split("=", 1)[1]
     return default
